import { base58 } from './utils/bytes.mjs';
import { uniqueBy } from './utils/arrays.mjs';

/**
 * The amount of bytes in a public key.
 * @category Signers and PublicKeys
 */
const PUBLIC_KEY_LENGTH = 32;

/**
 * Defines an object that has a public key.
 * @category Signers and PublicKeys
 */

/**
 * Creates a new public key from the given input.
 * @category Signers and PublicKeys
 */
const publicKey = input => {
  let key;
  // PublicKeyBase58.
  if (typeof input === 'string') {
    key = {
      bytes: base58.serialize(input)
    };
  }
  // HasPublicKey.
  else if (typeof input === 'object' && 'publicKey' in input) {
    key = {
      bytes: new Uint8Array(input.publicKey.bytes)
    };
  }
  // Web3JS-compatible PublicKey.
  else if (typeof input === 'object' && 'toBytes' in input) {
    key = {
      bytes: new Uint8Array(input.toBytes())
    };
  }
  // PublicKey.
  else if (isPublicKey(input)) {
    key = {
      bytes: new Uint8Array(input.bytes)
    };
  }
  // PublicKeyBytes.
  else {
    key = {
      bytes: new Uint8Array(input)
    };
  }
  assertPublicKey(key);
  return key;
};

/**
 * Creates the default public key which is composed of all zero bytes.
 * @category Signers and PublicKeys
 */
const defaultPublicKey = () => publicKey('11111111111111111111111111111111');

/**
 * Whether the given value is a valid public key.
 * @category Signers and PublicKeys
 */
const isPublicKey = value => typeof value === 'object' && typeof value.bytes === 'object' && typeof value.bytes.BYTES_PER_ELEMENT === 'number' && typeof value.bytes.length === 'number' && value.bytes.BYTES_PER_ELEMENT === 1 && value.bytes.length === PUBLIC_KEY_LENGTH;

/**
 * Whether the given value is a valid program-derived address.
 * @category Signers and PublicKeys
 */
const isPda = value => typeof value === 'object' && typeof value.bump === 'number' && isPublicKey(value);

/**
 * Ensures the given value is a valid public key.
 * @category Signers and PublicKeys
 */
function assertPublicKey(value) {
  if (!isPublicKey(value)) {
    throw new Error('Invalid public key');
  }
}

/**
 * Whether the given public keys are the same.
 * @category Signers and PublicKeys
 */
const samePublicKey = (left, right) => publicKey(left).bytes.toString() === publicKey(right).bytes.toString();

/**
 * Deduplicates the given array of public keys.
 * @category Signers and PublicKeys
 */
const uniquePublicKeys = publicKeys => uniqueBy(publicKeys, samePublicKey);

/**
 * Converts the given public key to a base58 string.
 * @category Signers and PublicKeys
 */
const base58PublicKey = key => base58.deserialize(publicKey(key).bytes)[0];

/**
 * Helper function that enables public keys and signers
 * to override the `isWritable` property of an account meta.
 * @category Signers and PublicKeys
 * @deprecated This function was used by Kinobi-generated libraries but
 * is no longer needed as they now export their helpers.
 */
const checkForIsWritableOverride = (account, value) => 'isWritable' in account && typeof account.isWritable === 'boolean' ? account.isWritable : value;

export { PUBLIC_KEY_LENGTH, assertPublicKey, base58PublicKey, checkForIsWritableOverride, defaultPublicKey, isPda, isPublicKey, publicKey, samePublicKey, uniquePublicKeys };
//# sourceMappingURL=PublicKey.mjs.map
