/**
 * The amount of bytes in a public key.
 * @category Signers and PublicKeys
 */
export declare const PUBLIC_KEY_LENGTH = 32;
/**
 * Defines an object that has a public key.
 * @category Signers and PublicKeys
 */
export type HasPublicKey = {
    publicKey: PublicKey;
};
/**
 * A base58 string that represents a public key.
 * @category Signers and PublicKeys
 */
export type PublicKeyBase58 = string;
/**
 * A Uint8Array that represents a public key.
 * @category Signers and PublicKeys
 */
export type PublicKeyBytes = Uint8Array;
/**
 * Defines all the possible inputs for creating a public key.
 * @category Signers and PublicKeys
 */
export type PublicKeyInput = HasPublicKey | PublicKey | PublicKeyBase58 | PublicKeyBytes | {
    toBytes: () => PublicKeyBytes;
};
/**
 * Defines a public key.
 * @category Signers and PublicKeys
 */
export type PublicKey = {
    readonly bytes: PublicKeyBytes;
};
/**
 * Defines a Program-Derived Address.
 *
 * It is a public key with the bump number that was used
 * to ensure the address is not on the ed25519 curve.
 *
 * @category Signers and PublicKeys
 */
export type Pda = PublicKey & {
    readonly bump: number;
};
/**
 * Creates a new public key from the given input.
 * @category Signers and PublicKeys
 */
export declare const publicKey: (input: PublicKeyInput) => PublicKey;
/**
 * Creates the default public key which is composed of all zero bytes.
 * @category Signers and PublicKeys
 */
export declare const defaultPublicKey: () => PublicKey;
/**
 * Whether the given value is a valid public key.
 * @category Signers and PublicKeys
 */
export declare const isPublicKey: (value: any) => value is PublicKey;
/**
 * Whether the given value is a valid program-derived address.
 * @category Signers and PublicKeys
 */
export declare const isPda: (value: any) => value is Pda;
/**
 * Ensures the given value is a valid public key.
 * @category Signers and PublicKeys
 */
export declare function assertPublicKey(value: any): asserts value is PublicKey;
/**
 * Whether the given public keys are the same.
 * @category Signers and PublicKeys
 */
export declare const samePublicKey: (left: PublicKeyInput, right: PublicKeyInput) => boolean;
/**
 * Deduplicates the given array of public keys.
 * @category Signers and PublicKeys
 */
export declare const uniquePublicKeys: (publicKeys: PublicKey[]) => PublicKey[];
/**
 * Converts the given public key to a base58 string.
 * @category Signers and PublicKeys
 */
export declare const base58PublicKey: (key: PublicKeyInput) => string;
/**
 * Helper function that enables public keys and signers
 * to override the `isWritable` property of an account meta.
 * @category Signers and PublicKeys
 * @deprecated This function was used by Kinobi-generated libraries but
 * is no longer needed as they now export their helpers.
 */
export declare const checkForIsWritableOverride: (account: (PublicKey | HasPublicKey) & {
    isWritable?: boolean;
}, value: boolean) => boolean;
